@@ -6,7 +6,7 @@ A thin wrapper around the standard Python argparse library.
 import logging as _logging
 
 from ._core import (
-    Arguments,
+    Config,
     MainType,
     NewCommand,
     Parser,
@@ -16,7 +16,7 @@ from ._core import (
 
 
 __all__ = [
-    "Arguments",
+    "Config",
     "MainType",
     "NewCommand",
     "Parser",
@@ -26,6 +26,6 @@ __all__ = [
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.3.1"
+__version__ = "0.5.0"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
